
CREATE TABLE DataFile (
       SuiteId              int NULL,
       FileId               int IDENTITY,
       script_id            int NULL,
       TestId               int NULL,
       Type                 smallint NULL,
       MachineId            int NULL,
       Name                 varchar(20) NULL,
       Location             varchar(255) NULL,
       StartTime            datetime NULL
)
go


ALTER TABLE DataFile
       ADD PRIMARY KEY NONCLUSTERED (FileId)
go

exec sp_primarykey DataFile,
       FileId
go

CREATE TABLE DataFileDetail (
       FileDetailId         int IDENTITY,
       FileId               int NULL,
       Operation            varchar(255) NULL,
       ClientHost           varchar(50) NULL,
       StartTime            datetime NULL,
       EndTime              datetime NULL,
       TimeToComplete       float NULL,
       IISBytesSent         int NULL,
       IISBytesReceived     int NULL,
       IISServiceStatus     int NULL,
       SQLReads             int NULL,
       SQLWrites            int NULL
)
go


ALTER TABLE DataFileDetail
       ADD PRIMARY KEY (FileDetailId)
go

exec sp_primarykey DataFileDetail,
       FileDetailId
go

CREATE TABLE FileType (
       Type                 smallint NOT NULL,
       NamingConvention     varchar(20) NULL,
       Description          varchar(50) NULL
)
go


ALTER TABLE FileType
       ADD PRIMARY KEY NONCLUSTERED (Type)
go

exec sp_primarykey FileType,
       Type
go

CREATE TABLE IISCpuPerfMon (
       SuiteId              int NULL,
       TestId               int NULL,
       SampleTime           varchar(50) NULL,
       Processor1           float NULL,
       Processor0           float NULL,
       PhysicalDiskWritesSec float NULL,
       PhysicalDiskReadsSec float NULL,
       PhysicalDiskAvgDiskWrites float NULL,
       PyhsicalDiskAvgDiskReads float NULL,
       PhysicalDiskPctDiskWriteTime float NULL,
       PhysicalDiskPctDiskReadTime float NULL,
       MemoryPageFaultsSec  float NULL,
       LogicalDiskDiskWritesSec float NULL,
       LogicalDiskDiskReadsSec float NULL,
       LogicalDiskAvgDiskWrite float NULL,
       LogicalDiskAvgDiskRead float NULL,
       LogicalDiskPctWriteTime float NULL,
       LogicalDiskPctDiskReadTime float NULL,
       HTTPServiceBytesSentSec float NULL,
       HTTPServiceBytesReceivedSec float NULL,
       ASPRequestsSec       float NULL,
       ASPRequestsTimedOut  float NULL,
       ASPRequestsCurrent   float NULL,
       ASPRequestWaitTime   float NULL,
       ASPMemoryAllocated   float NULL
)
go


CREATE TABLE IISCpuPerfMonScratch (
       SampleTime           varchar(50) NULL,
       Processor1           float NULL,
       Processor0           float NULL,
       PhysicalDiskWritesSec float NULL,
       PhysicalDiskReadsSec float NULL,
       PhysicalDiskAvgDiskWrites float NULL,
       PyhsicalDiskAvgDiskReads float NULL,
       PhysicalDiskPctDiskWriteTime float NULL,
       PhysicalDiskPctDiskReadTime float NULL,
       MemoryPageFaultsSec  float NULL,
       LogicalDiskDiskWritesSec float NULL,
       LogicalDiskDiskReadsSec float NULL,
       LogicalDiskAvgDiskWrite float NULL,
       LogicalDiskAvgDiskRead float NULL,
       LogicalDiskPctWriteTime float NULL,
       LogicalDiskPctDiskReadTime float NULL,
       HTTPServiceBytesSentSec float NULL,
       HTTPServiceBytesReceivedSec float NULL,
       ASPRequestsSec       float NULL,
       ASPRequestsTimedOut  float NULL,
       ASPRequestsCurrent   float NULL,
       ASPRequestWaitTime   float NULL,
       ASPMemoryAllocated   float NULL
)
go


CREATE TABLE InetLoad (
       LogTime              varchar(30) NOT NULL,
       ClientHost           varchar(30) NOT NULL,
       ServerIp             varchar(50) NULL,
       Operation            varchar(255) NULL
)
go

CREATE INDEX ixinetload ON InetLoad
(
       ClientHost,
       LogTime
)
go


CREATE TABLE InetLoadScratch (
       OneLine              varchar(255) NULL
)
go


CREATE TABLE inetlog (
       ClientHost           varchar(255) NOT NULL,
       username             varchar(255) NOT NULL,
       LogTime              datetime NOT NULL,
       LogDate              datetime NULL,
       service              varchar(255) NOT NULL,
       machine              varchar(255) NOT NULL,
       serverip             varchar(50) NOT NULL,
       processingtime       int NOT NULL,
       bytesrecvd           int NOT NULL,
       bytessent            int NOT NULL,
       servicestatus        int NOT NULL,
       win32status          int NOT NULL,
       operation            varchar(255) NOT NULL,
       target               varchar(255) NOT NULL,
       parameters           varchar(255) NOT NULL
)
go


CREATE TABLE machine (
       MachineId            int IDENTITY (1,1),
       MachineName          varchar(20) NULL,
       MachineDescription   varchar(255) NULL,
       MachineType          varchar(20) NULL,
       NumberOfProcessors   tinyint NULL,
       ProcessorType        varchar(20) NULL,
       NumberofControllers  tinyint NULL,
       RAM                  smallint NULL,
       TotalDisk            float NULL,
       NIC                  varchar(50) NULL
)
go


ALTER TABLE machine
       ADD PRIMARY KEY NONCLUSTERED (MachineId)
go

exec sp_primarykey machine,
       MachineId
go

CREATE TABLE MachineProcessEnvironment (
       SuiteId              int NOT NULL,
       MachineId            int NOT NULL
)
go


ALTER TABLE MachineProcessEnvironment
       ADD PRIMARY KEY (SuiteId, MachineId)
go

exec sp_primarykey MachineProcessEnvironment,
       SuiteId,
       MachineId
go

CREATE TABLE script (
       script_id            int NOT NULL,
       script_name          varchar(50) NULL,
       script_location      varchar(255) NULL,
       script_description   varchar(255) NULL,
       script_type          int NULL
)
go

CREATE UNIQUE INDEX PrimaryKey ON script
(
       script_id
)
go

CREATE UNIQUE INDEX script_name ON script
(
       script_name
)
go


ALTER TABLE script
       ADD PRIMARY KEY NONCLUSTERED (script_id)
go

exec sp_primarykey script,
       script_id
go

CREATE TABLE ScriptType (
       script_type          int NOT NULL,
       script_description   varchar(255) NULL
)
go


ALTER TABLE ScriptType
       ADD PRIMARY KEY NONCLUSTERED (script_type)
go

exec sp_primarykey ScriptType,
       script_type
go

CREATE TABLE SQLCpuPerfMon (
       SuiteId              int NULL,
       TestId               int NULL,
       SampleTime           varchar(50) NULL,
       SQLServerIOTransactionsSec float NULL,
       SQLServerIOPageReadsSec float NULL,
       SQLServerIOLogWritesSec float NULL,
       SQLServerIOBatchWritesSec float NULL,
       Processor0           float NULL,
       PhysicalDiskWritesSec float NULL,
       PhysicalDiskReadsSec float NULL,
       PhysicalDiskAvgDiskWrites float NULL,
       PyhsicalDiskAvgDiskReads float NULL,
       PhysicalDiskPctDiskWriteTime float NULL,
       PhysicalDiskPctDiskReadTime float NULL,
       MemoryPageFaultsSec  float NULL,
       LogicalDiskDiskWritesSec float NULL,
       LogicalDiskDiskReadsSec float NULL,
       LogicalDiskAvgDiskWrite float NULL,
       LogicalDiskAvgDiskRead float NULL,
       LogicalDiskPctWriteTime float NULL,
       LogicalDiskPctDiskReadTime float NULL
)
go


CREATE TABLE SQLCpuPerfMonScratch (
       SampleTime           varchar(50) NULL,
       SQLServerIOTransactionsSec float NULL,
       SQLServerIOPageReadsSec float NULL,
       SQLServerIOLogWritesSec float NULL,
       SQLServerIOBatchWritesSec float NULL,
       Processor0           float NULL,
       PhysicalDiskWritesSec float NULL,
       PhysicalDiskReadsSec float NULL,
       PhysicalDiskAvgDiskWrites float NULL,
       PyhsicalDiskAvgDiskReads float NULL,
       PhysicalDiskPctDiskWriteTime float NULL,
       PhysicalDiskPctDiskReadTime float NULL,
       MemoryPageFaultsSec  float NULL,
       LogicalDiskDiskWritesSec float NULL,
       LogicalDiskDiskReadsSec float NULL,
       LogicalDiskAvgDiskWrite float NULL,
       LogicalDiskAvgDiskRead float NULL,
       LogicalDiskPctWriteTime float NULL,
       LogicalDiskPctDiskReadTime float NULL
)
go


CREATE TABLE Test (
       TestId               int NOT NULL,
       SuiteId              int NOT NULL,
       ScenarioName         varchar(50) NULL,
       StartTime            datetime NULL,
       EndTime              datetime NULL,
       TestComments         varchar(255) NULL
)
go


ALTER TABLE Test
       ADD PRIMARY KEY NONCLUSTERED (SuiteId, TestId)
go

exec sp_primarykey Test,
       SuiteId,
       TestId
go

CREATE TABLE testsuite (
       SuiteId              int NOT NULL,
       Name                 varchar(20) NULL,
       TotalUserSimulated   int NULL,
       Description          varchar(255) NULL
)
go


ALTER TABLE testsuite
       ADD PRIMARY KEY NONCLUSTERED (SuiteId)
go

exec sp_primarykey testsuite,
       SuiteId
go

ALTER TABLE DataFile
       ADD FOREIGN KEY (script_id)
                             REFERENCES script
go


ALTER TABLE DataFile
       ADD FOREIGN KEY (MachineId)
                             REFERENCES machine
go


ALTER TABLE DataFile
       ADD FOREIGN KEY (SuiteId, TestId)
                             REFERENCES Test
go


ALTER TABLE DataFile
       ADD FOREIGN KEY (Type)
                             REFERENCES FileType
go


exec sp_foreignkey DataFile, script,
       script_id
go

exec sp_foreignkey DataFile, machine,
       MachineId
go

exec sp_foreignkey DataFile, Test,
       SuiteId,
       TestId
go

exec sp_foreignkey DataFile, FileType,
       Type
go

ALTER TABLE DataFileDetail
       ADD FOREIGN KEY (FileId)
                             REFERENCES DataFile
go


exec sp_foreignkey DataFileDetail, DataFile,
       FileId
go

ALTER TABLE MachineProcessEnvironment
       ADD FOREIGN KEY (SuiteId)
                             REFERENCES testsuite
go


ALTER TABLE MachineProcessEnvironment
       ADD FOREIGN KEY (MachineId)
                             REFERENCES machine
go


exec sp_foreignkey MachineProcessEnvironment, testsuite,
       SuiteId
go

exec sp_foreignkey MachineProcessEnvironment, machine,
       MachineId
go

ALTER TABLE script
       ADD FOREIGN KEY (script_type)
                             REFERENCES ScriptType
go


exec sp_foreignkey script, ScriptType,
       script_type
go

ALTER TABLE Test
       ADD FOREIGN KEY (SuiteId)
                             REFERENCES testsuite
go


exec sp_foreignkey Test, testsuite,
       SuiteId
go


